@@ -1,5 +1,7 @@
+from typing import List
 from schema import Schema, Optional
 from datetime import date, datetime
+from pydantic import BaseModel, root_validator
 
 
 project_info_schema = Schema(
@@ -159,3 +161,22 @@ def fields(schema):
         elif isinstance(ff.schema, str):
             fields.append(ff.schema)
     return fields
+
+
+class TextureProfilerLoaderInputData(BaseModel):
+    folder: str
+    filename: str
+    station_no: int
+    datetime: datetime
+    mpd: float
+    stdev: float
+    valid_segments: int
+    proportion_valid_segments: float
+    is_valid: bool
+    trace: List[dict]
+
+    @root_validator
+    def convert_field_names(cls, values):
+        values["station_no"] = values.pop("file_number")
+        values["mpd"] = values.pop("mean")
+        return values
